<?php
/**
 * Theme functions and definitions
 *
 * @package Bosa News Blog 1.0.0
 */

require get_stylesheet_directory() . '/inc/customizer/customizer.php';
require get_stylesheet_directory() . '/inc/customizer/loader.php';
require get_stylesheet_directory() . '/inc/child-functions.php';

if ( ! function_exists( 'bosa_news_blog_enqueue_styles' ) ) :
	/**
	 * @since Bosa News Blog 1.0.0
	 */
	function bosa_news_blog_enqueue_styles() {
		wp_enqueue_style( 'bosa-news-blog-style-parent', get_template_directory_uri() . '/style.css',
			array(
				'bootstrap',
				'slick',
				'slicknav',
				'slick-theme',
				'fontawesome',
				'bosa-blocks',
				'bosa-google-font'
				)
		);

		wp_enqueue_style( 'bosa-news-blog-google-fonts', "https://fonts.googleapis.com/css2?family=Montserrat:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap", false );
		wp_enqueue_style( 'bosa-news-blog-google-fonts-two', "https://fonts.googleapis.com/css2?family=Open+Sans:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;1,300;1,400;1,500;1,600;1,700;1,800&display=swap", false );

	}

endif;
add_action( 'wp_enqueue_scripts', 'bosa_news_blog_enqueue_styles', 1 );

if ( ! function_exists( 'bosa_news_blog_modify_locale' ) ) :
	/**
	 * Modifies the localized array
	 *
	 * @since Bosa News Blog 1.0.0
	 * @return array
	 */
	function bosa_news_blog_modify_locale( $locale ) {

		if( isset( $locale['home_highlight_posts'] ) ){
			$locale['home_highlight_posts'] = array(
				'autoplay'      => absint( !get_theme_mod( 'disable_highlight_posts_autoplay', true ) ),
				'autoplaySpeed' => absint( get_theme_mod( 'highlight_posts_autoplay_speed', 4 ) * 1000 ),
				'slidesToShow'  => absint( get_theme_mod( 'highlight_posts_slides_show', 4 ) ),
			);
		 }
		return $locale;	
	}
	add_filter( 'bosa_localize_var', 'bosa_news_blog_modify_locale' );
endif;

function bosa_header_advertisement_banner(){
	$bannerImageID = get_theme_mod( 'header_advertisement_banner', '' );
	$header_advertisement_banner_obj = wp_get_attachment_image_src( $bannerImageID, 'bosa-730-90' );
	if ( is_array(  $header_advertisement_banner_obj ) ){
		$header_advertisement_banner = $header_advertisement_banner_obj[0];
	}else{
		$header_advertisement_banner = '';
	}
	$alt = get_post_meta( $bannerImageID, '_wp_attachment_image_alt', true);
 	?>
	 	<div class="header-advertisement-banner">
	 		<a href="<?php echo esc_url( get_theme_mod( 'header_advertisement_banner_link', '' ) ); ?>" alt="<?php echo $alt; ?>" target="_blank">
	 			<img src="<?php echo esc_url( $header_advertisement_banner ); ?>">
	 		</a>
	 	</div>
	<?php
}

add_theme_support( "title-tag" );
add_theme_support( 'automatic-feed-links' );